%
% function Y_tilde = CPPCA_Encoder(X, P)
%
%   This function implements the CPPCA encoder.
%  
%   X is an N x M dataset, and P is a length-J cell array of N x K
%   projection matrices.
%
%   Y is returned as a length-J cell array.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function [Y_tilde, X] = CPPCA_Encoder(X, P)

[N M] = size(X);
J = length(P);
[N K] = size(P{1});

for j = 1:J
  X2{j} = X(:, j:J:M);
  Y_tilde{j} = P{j}' * X2{j};
end

X = X2;
