%
% function P = CPPCA_GenerateProjections(N, K, J, filename)
%
%   This function generates the J random projection matrices
%   P, each of which is N x K.
%
%   P is returned as a length-J cell array of N x K matrices.
%
%   If filename is not specified, the P cell array is generated
%   randomly and returned. If filename is specified, but the file does
%   not exist, P is generated randomly and written to
%   filename. Finally, if the file does exist, P is simply read from
%   the file.
%
%   In all cases, P is generated as random N x N matrices and then
%   truncated to K columns. P is stored in filename as N x N matrices
%   and truncated to K columns upon reading.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function P = CPPCA_GenerateProjections(N, K, J, filename)

if ((nargin == 4) && exist(filename, 'file'))
    load(filename);
else
  for j = 1:J
    P{j} = randn(N, N);
    P{j} = orth(P{j});
  end
end

if ((nargin == 4) && (~exist(filename, 'file')))
  save(filename, 'P');
end

for j = 1:J
  P{j} = P{j}(:, 1:K);
end
