%
% H = Channel_Entropy(stream)
%
% stream: (1 x N)
%
% H: scalar
%
% Computes the entropy of symbol stream.  Symbols must be >= 0.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function H = Channel_Entropy(stream);

stream = stream(:)';
N = size(stream, 2);

num_symbols = max(stream) + 1;
if (min(stream) < 0)
  error('entropy2: symbols must be >= 0')
end

probs = zeros(1, num_symbols);

for i = 1:N
  symbol = stream(i);
  probs(symbol + 1) = probs(symbol + 1) + 1;
end
  
probs = probs / N;

probs = probs(probs > 0);
H = -sum(probs .* log(probs));
H = H ./ log(2);
