% 
% function Psi = PCA_Train(X)
% 
%   This function designs the PCA transform matrix for the columns
%   of N x M matrix X, where M indicates the number of N-dimensional
%   vectors are in the dataset. The transform matrix, Psi, is
%   N x N. X is assumed to have zero mean.
%
%   The basis vectors of the transform are the columns of Psi. If x is a
%   vector from X, the PCA transform, x_check, of x can be 
%   calculated from Psi as
%     x_check = Psi'*x
%   The original vector can be obtained from x_check as
%     x = Psi*x_check
%


%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function Psi = PCA_Train(X)

[N M] = size(X);

Sigma = (X * X')/M;
  
[Psi, S, V] = svd(Sigma);
