%
% function Run_TIP_Fig2()
%
%   This function reproduces results from the paper:
%     J. E. Fowler, "Compressive-Projection Principal Component
%       Analysis," submitted to IEEE Transactions on Image Processing,
%       June 2008. Revised February 2009.
%  
%   Specifically, this function produces Fig. 2.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function Run_TIP_Fig2()

delta1 = 1000;

deltas = logspace(-2, 1, 10);

N = 100;

Ks = [10 20 30 40 50 60];
styles = {'k-', 'k--', 'k-.', 'k-x', 'k--x', 'k-o'};

figure(1);
clf;

legend_string = {};

for curve = 1:length(Ks)
  K = Ks(curve);
  
  bound = 4*deltas*(N-2)/delta1/(K-2);
  bound(bound > 1) = 1;
  
  angle = asin(bound)/pi*180;
  
  loglog(deltas/delta1, angle, styles{curve}, 'LineWidth', 2);
  hold on

  legend_string{curve} = ['K/N = ' num2str(K/N)];
end

grid on
xlabel('\delta/\delta_1');
ylabel('Expected Bound on \omega_1 (degrees)')
legend(legend_string, 'Location', 'NorthWest');
