%
% function Run_TIP_Fig3()
%
%   This function reproduces results from the paper:
%     J. E. Fowler, "Compressive-Projection Principal Component
%       Analysis," submitted to IEEE Transactions on Image Processing,
%       June 2008. Revised February 2009.
%  
%   Specifically, this function produces Fig. 3.
%  
%   Note: since this code relies on randomly generated
%   projection matrices, your results may differ slightly
%   in appearance and value from those in the paper.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function Run_TIP_Fig3()

delta1 = 1000;
lambda1 = delta1 + 1;

lambda2s = logspace(-2, 1, 10) + 1;

N = 100;

Ks = [10 20 30 40 50 60];
styles = {'k-', 'k--', 'k-.', 'k-x', 'k--x', 'k-o'};

figure(1);
clf;

legend_string = {};

W = orth(randn(N, N));
w1 = W(:, 1);

num_trials = 1000;

for curve = 1:length(Ks)
  K = Ks(curve);
  
  for i = 1:length(lambda2s)
    lambda2 = lambda2s(i);

    Lambda = diag([lambda1 lambda2 ones(1, N - 2)]);
    Sigma = W * Lambda * W';
    Delta = Lambda - eye(N);
    Delta(1, 1) = 0;
    delta(i) = trace(Delta);
    
    for trial = 1:num_trials
      P = randn(N, K);
      P = orth(P);
      Sigma_tilde = P' * Sigma * P;
      
      [U_tilde Lambda_tilde V] = svd(Sigma_tilde);
      u1_tilde = U_tilde(:, 1);
      s = SAM(u1_tilde, P'*w1);
      if (s > 90);
        s = 180 - s;
      end
      omega1(trial, i) = s/pi*180;
    end
  end
  
  loglog(delta/delta1, mean(omega1), styles{curve}, 'LineWidth', 2);
  hold on

  legend_string{curve} = ['K/N = ' num2str(K/N)];
end

grid on
xlabel('\delta/\delta_1');
ylabel('Actual \omega_1 (degrees)')
legend(legend_string, 'Location', 'NorthWest');
axis([10e-5 10e-2 10e-3 10e2]);
