%
% function Run_TIP_Fig4()
%
%   This function reproduces results from the paper:
%     J. E. Fowler, "Compressive-Projection Principal Component
%       Analysis," submitted to IEEE Transactions on Image Processing,
%       June 2008. Revised February 2009.
%  
%   Specifically, this function produces Fig. 4.
%  
%   Note: since this code relies on randomly generated
%   projection matrices, your results may differ slightly
%   in appearance and value from those in the paper.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function Run_TIP_Fig4()

N = 100;
K = 40;

Lambda = diag([10000 1000 100 10 ones(1, N - 4)]);
W = orth(randn(N, N));
Sigma = W * Lambda * W';

num_trials = 1000;

for trial = 1:num_trials
  P = randn(N, K);
  P = orth(P);
  [U_tilde Lambda_tilde V] = svd(P' * Sigma * P);
  U = P * U_tilde;
  for i = 1:K
    u = U(:, i);
    s = SAM(u, P*P'*W(:, i));
    if (s > 90);
      s = 180 - s;
    end
    omega(trial, i) = s;
  end
end

clf;

subplot(2,2,1);
hist(omega(:, 1), linspace(0, 90, 100));
h = findobj(gca,'Type','patch');
set(h, 'FaceColor', 'k');
A = axis;
A(1) = 0;
A(2) = 90;
axis(A);
ylabel('Frequency');
xlabel('Angle \omega_1 (degrees)');
disp(['Average omega1 = ' num2str(mean(omega(:,1))) ' degrees']);

subplot(2,2,2);
hist(omega(:, 2), linspace(0, 90, 100));
h = findobj(gca,'Type','patch');
set(h, 'FaceColor', 'k');
A = axis;
A(1) = 0;
A(2) = 90;
axis(A);
ylabel('Frequency');
xlabel('Angle \omega_2 (degrees)');
disp(['Average omega2 = ' num2str(mean(omega(:,2))) ' degrees']);

subplot(2,2,3);
hist(omega(:, 3), linspace(0, 90, 100));
h = findobj(gca,'Type','patch');
set(h, 'FaceColor', 'k');
A = axis;
A(1) = 0;
A(2) = 90;
axis(A);
ylabel('Frequency');
xlabel('Angle \omega_3 (degrees)');
disp(['Average omega3 = ' num2str(mean(omega(:,3))) ' degrees']);

subplot(2,2,4);
hist(omega(:, 4), linspace(0, 90, 100));
h = findobj(gca,'Type','patch');
set(h, 'FaceColor', 'k');
A = axis;
A(1) = 0;
A(2) = 90;
axis(A);
ylabel('Frequency');
xlabel('Angle \omega_4 (degrees)');
disp(['Average omega4 = ' num2str(mean(omega(:,4))) ' degrees']);
