%
% function Run_TIP_Fig8()
%
%   This function reproduces results from the paper:
%     J. E. Fowler, "Compressive-Projection Principal Component
%       Analysis," submitted to IEEE Transactions on Image Processing,
%       June 2008. Revised February 2009.
%  
%   Specifically, this function produces Figs. 8 and 9.
%  
%   Note: since this code relies on randomly generated
%   projection matrices, your results may differ slightly
%   in appearance and value from those in the paper.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function Run_TIP_Fig8()

N = 100;

Ks = round(N * linspace(0.1, 0.5, 20));
Js = [3 5 10 20 50];
lines = {'k-' 'k--' 'k-.' 'k-x' 'k--x'};

Lambda = diag([10000 1000 100 10 ones(1, N - 4)]);
W = orth(randn(N, N));
Sigma = W * Lambda * W';

num_trials = 100;
iterations = 1000;
  
for l = 1:2
  disp(['Running xi' num2str(l)]);
  
  xi = zeros(num_trials, length(Ks), length(Js));
  
  for index2 = 1:length(Js)
    disp(['  Running J = ' num2str(Js(index2))]);
    for index1 = 1:length(Ks)
      for trial = 1:num_trials
        K = Ks(index1);
        J = Js(index2);
        
        QQ = [];
        w_hat = 0;
        for j = 1:J
          P = randn(N, K);
          P = orth(P);
          [U_tilde Lambda_tilde V] = svd(P' * Sigma * P);
          U = P * U_tilde;
          Q = [U(:, l) null(P')];
          QQ = [QQ Q * Q'];
          w_hat = w_hat + U(:, l);
        end
        w_hat = w_hat / J;

        for i = 1:iterations
          w_hat = QQ * repmat(w_hat, [J 1]) / J;
        end
	s = SAM(W(:, l), w_hat);
	if (s > 90)
	  s = 180 - s;
	end  
        
        xi(trial, index1, index2) = s;
      end
    end
  end
  
  xi_avg = mean(xi, 1);
  
  figure(l);
  for index2 = 1:length(Js)
    J = Js(index2);
    plot(Ks/N, xi_avg(1, :, index2), lines{index2}, 'LineWidth', 2);
    M{index2} = ['J = ' num2str(Js(index2))];
    hold on
  end
  grid on
  ylabel(['Average \xi_' num2str(l) ' (degrees)']);
  xlabel('Relative subspace dimension, K/N');
  legend(M, 'Location', 'NorthEast');
end
