%
% function D = SNR_Dataset(X, X_check, Psi)
%
%    This function calculates the SNR averaged over all vectors
%    of two datasets.
%
%    Both X and X_check are length-J cell arrays of N x Mj matrices.
%    Psi is and N x N transform array that transform X_check
%    back into the original-signal domain before calculating the
%    SNR with X.
%
% function D = SNR_Dataset(X, X_hat)
%
%    This variation of the function assumes that the second argument
%    is in the original-signal domain already, and so the SNR with X
%    is calculated directly.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function D = SNR_Dataset(X, X_check, Psi)

if (nargin == 3)
  D = mean(SNR(cell2mat(X), Psi * cell2mat(X_check)));
else
  D = mean(SNR(cell2mat(X), cell2mat(X_check)));
end
