% 
% function [x_hat channel] = USQ(x, q)
% 
%   This function implements uniform scalar quantization (USQ) of the
%   dataset given by x, returning the reconstruction in x_hat. q gives
%   the quantization stepsize, while the quantization indices are
%   returned in channel.
%

%
% CPPCA: Compressive-Projection Principal Component Analysis
% Copyright (C) 2007-2014  James E. Fowler
% http://www.ece.mstate.edu/~fowler
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%


function [x_hat channel] = USQ(x, q)

J = length(x);

channel = [];
for j = 1:J
  [N M] = size(x{j});
  x2 = x{j}(:);
  i = round(x2 / q - 0.5);
  x_hat{j} = reshape((i + 0.5) * q, [N M]);
  channel = [channel ; i];
end
